@@ -36,12 +36,12 @@ class KGAPIBLOGGER_EXPORT PageModifyJob : public KGAPI2::ModifyJob
   public:
     explicit PageModifyJob(const PagePtr &page,
                            const AccountPtr &account,
-                           QObject *parent = 0);
+                           QObject *parent = nullptr);
     virtual ~PageModifyJob();
 
   protected:
-    void start() Q_DECL_OVERRIDE;
-    ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) Q_DECL_OVERRIDE;
+    void start() override;
+    ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
   private:
     class Private;
