@@ -3,20 +3,21 @@
  *
  * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * GNU Lesser General Public License for more details.
  *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_JOB_H
@@ -84,7 +85,7 @@ class KGAPICORE_EXPORT Job : public QObject
      *
      * @param parent
      */
-    explicit Job(QObject* parent = Q_NULLPTR);
+    explicit Job(QObject* parent = nullptr);
 
     /**
      * @brief Constructor for jobs that require authentication
@@ -93,7 +94,7 @@ class KGAPICORE_EXPORT Job : public QObject
      * @param parent
      * @see Job::Account, Job::setAccount
      */
-    explicit Job(const AccountPtr &account, QObject* parent = Q_NULLPTR);
+    explicit Job(const AccountPtr &account, QObject* parent = nullptr);
 
     /**
      * @brief Destructor
@@ -326,12 +327,6 @@ class KGAPICORE_EXPORT Job : public QObject
     friend class Private;
 
     friend class AuthJob;
-
-    Q_PRIVATE_SLOT(d, void _k_doStart())
-    Q_PRIVATE_SLOT(d, void _k_doEmitFinished())
-    Q_PRIVATE_SLOT(d, void _k_replyReceived(QNetworkReply *reply))
-    Q_PRIVATE_SLOT(d, void _k_dispatchTimeout())
-
 };
 
 } // namespace KGAPI2
