@@ -42,7 +42,7 @@ class KGAPICORE_EXPORT FeedData {
         startIndex(0),
         itemsPerPage(0),
         totalResults(0)
-    { };
+    { }
 
     int startIndex;     /**< Index of first item on current feed page. */
     int itemsPerPage;   /**< Number of items per feed page. This will be same 
@@ -164,7 +164,7 @@ typedef QList<PostPtr> PostsList;
 template<class T>
 ObjectsList operator<<(ObjectsList &objectsList, const QList< QSharedPointer<T> > &list)
 {
-    Q_FOREACH (const QSharedPointer<T> &item, list) {
+    for (const QSharedPointer<T> &item : list) {
         objectsList << item;
     }
 
