@@ -27,8 +27,8 @@
 #include "driveservice.h"
 #include "utils.h"
 
-#include <QtNetwork/QNetworkReply>
-#include <QtNetwork/QNetworkRequest>
+#include <QNetworkReply>
+#include <QNetworkRequest>
 
 
 using namespace KGAPI2;
