@@ -26,7 +26,7 @@
 #include "deletejob.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 namespace KGAPI2
 {
@@ -42,23 +42,23 @@ class KGAPIDRIVE_EXPORT ChildReferenceDeleteJob : public KGAPI2::DeleteJob
     explicit ChildReferenceDeleteJob(const QString &folderId,
                                      const QString &childId,
                                      const AccountPtr &account,
-                                     QObject *parent = 0);
+                                     QObject *parent = nullptr);
     explicit ChildReferenceDeleteJob(const QString &folderId,
                                      const QStringList &childrenIds,
                                      const AccountPtr &account,
-                                     QObject *parent = 0);
+                                     QObject *parent = nullptr);
     explicit ChildReferenceDeleteJob(const QString &folderId,
                                      const ChildReferencePtr &reference,
                                      const AccountPtr &account,
-                                     QObject *parent = 0);
+                                     QObject *parent = nullptr);
     explicit ChildReferenceDeleteJob(const QString &folderId,
                                      const ChildReferencesList &references,
                                      const AccountPtr &account,
-                                     QObject *parent = 0);
+                                     QObject *parent = nullptr);
     virtual ~ChildReferenceDeleteJob();
 
   protected:
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
   private:
     class Private;
