@@ -1,18 +1,21 @@
 /*
     Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
+    This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    GNU Lesser General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef LIBKGAPI2_DRIVEFILE_H
@@ -47,10 +50,10 @@ namespace Drive
  */
 class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
 {
-
-  public:
+  private:
     class Private;
 
+  public:
     /**
      * @brief DriveFile::Labels holds the structure used for labels property.
      */
@@ -74,16 +77,21 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
         void setStarred(bool starred);
 
         /**
-         * @brief Returns whether this file is hidden from the user.
+         * @brief Returns whether this file has the 'hidden' label set.
+         * @deprecated The 'hidden' label has been deprecated in the v2 api and removed in the v3 one.
+         *             You can just ignore it.
          */
-        bool hidden() const;
+#ifndef KGAPIDRIVE_NO_DEPRECATED
+        KGAPIDRIVE_DEPRECATED bool hidden() const;
+#endif
 
         /**
-         * @brief Sets whether this file is hidden from the user
-         *
-         * @param hidden
+         * @brief Sets whether this file has the 'hidden' label set.
+         * @deprecated The 'hidden' label has been deprecated in the v2 api and removed in the v3 one.
          */
-        void setHidden(bool hidden);
+#ifndef KGAPIDRIVE_NO_DEPRECATED
+        KGAPIDRIVE_DEPRECATED void setHidden(bool hidden);
+#endif
 
         /**
          * @brief Returns whether this file has been trashed.
@@ -295,6 +303,16 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
 
     typedef QSharedPointer<Thumbnail> ThumbnailPtr;
 
+    /**
+     * @brief JSON serialization options.
+     * @since 5.3.1
+     */
+    enum SerializationOption {
+        NoOptions = 0,             ///< No option set.
+        ExcludeCreationDate = 1    ///< Exclude 'createdDate' entry. This is necessary when renaming URLs.
+    };
+    Q_DECLARE_FLAGS(SerializationOptions, SerializationOption)
+
     explicit File();
     explicit File(const File &other);
     virtual ~File();
@@ -574,17 +592,22 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
 
     static FilePtr fromJSON(const QByteArray &jsonData);
     static FilesList fromJSONFeed(const  QByteArray &jsonData, FeedData &feedData);
-    static QByteArray toJSON(const FilePtr &file);
+    static QByteArray toJSON(const FilePtr &file, SerializationOptions options = NoOptions);
 
     static FilePtr fromJSON(const QVariantMap &jsonData);
 
 private:
     Private * const d;
     friend class Private;
+    friend class Change::Private;
+    friend class ParentReference;
+    friend class Permission;
 };
 
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(KGAPI2::Drive::File::SerializationOptions)
+
 #endif // LIBKGAPI2_DRIVEFILE_H
