@@ -3,20 +3,21 @@
  *
  * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * GNU Lesser General Public License for more details.
  *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef KGAPI2_DRIVEFILECOPYJOB_H
@@ -25,7 +26,7 @@
 #include "fileabstractdatajob.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QMap>
+#include <QMap>
 
 namespace KGAPI2
 {
@@ -40,29 +41,29 @@ class KGAPIDRIVE_EXPORT FileCopyJob : public KGAPI2::Drive::FileAbstractDataJob
   public:
     explicit FileCopyJob(const QString &sourceFileId,
                          const FilePtr &destinationFile,
-                         const AccountPtr &account, QObject *parent = 0);
+                         const AccountPtr &account, QObject *parent = nullptr);
     explicit FileCopyJob(const FilePtr &sourceFile,
                          const FilePtr &destinationFile,
-                         const AccountPtr &account, QObject *parent = 0);
+                         const AccountPtr &account, QObject *parent = nullptr);
     explicit FileCopyJob(const QMap < QString /* source file id */,
                          FilePtr /* destination file */ > &files,
-                         const AccountPtr &account, QObject *parent = 0);
+                         const AccountPtr &account, QObject *parent = nullptr);
     explicit FileCopyJob(const QMap < FilePtr /* source file */,
                          FilePtr /* destination file */ > &files,
-                         const AccountPtr &account, QObject *parent = 0);
+                         const AccountPtr &account, QObject *parent = nullptr);
     virtual ~FileCopyJob();
 
     FilesList files() const;
 
   protected:
-    virtual void handleReply(const QNetworkReply *reply,
-                             const QByteArray &rawData);
+    void handleReply(const QNetworkReply *reply,
+                             const QByteArray &rawData) override;
 
-    virtual void dispatchRequest(QNetworkAccessManager *accessManager,
+    void dispatchRequest(QNetworkAccessManager *accessManager,
                                  const QNetworkRequest &request,
                                  const QByteArray &data,
-                                 const QString &contentType);
-    virtual void start();
+                                 const QString &contentType) override;
+    void start() override;
 
   private:
     class Private;
