@@ -25,7 +25,7 @@
 #include "driveservice.h"
 #include "file.h"
 
-#include <QtNetwork/QNetworkRequest>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
@@ -69,7 +69,7 @@ FileDeleteJob::FileDeleteJob(const FilesList &files,
     DeleteJob(account, parent),
     d(new Private)
 {
-    Q_FOREACH(const FilePtr & file, files) {
+    for (const FilePtr & file : qAsConst(files)) {
         d->filesIDs << file->id();
     }
 }
