@@ -26,8 +26,7 @@
 #include "fetchjob.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QStringList>
-#include <QtCore/QMap>
+#include <QStringList>
 
 namespace KGAPI2
 {
@@ -107,12 +106,12 @@ class KGAPIDRIVE_EXPORT FileFetchJob : public KGAPI2::FetchJob
     };
 
     explicit FileFetchJob(const QString &fileId,
-                          const AccountPtr &account, QObject *parent = 0);
+                          const AccountPtr &account, QObject *parent = nullptr);
     explicit FileFetchJob(const QStringList &filesIds,
-                          const AccountPtr &account, QObject *parent = 0);
+                          const AccountPtr &account, QObject *parent = nullptr);
     explicit FileFetchJob(const FileSearchQuery &query,
-                          const AccountPtr &account, QObject *parent = 0);
-    explicit FileFetchJob(const AccountPtr &account, QObject *parent = 0);
+                          const AccountPtr &account, QObject *parent = nullptr);
+    explicit FileFetchJob(const AccountPtr &account, QObject *parent = nullptr);
     virtual ~FileFetchJob();
 
     bool updateViewedDate() const;
@@ -122,9 +121,9 @@ class KGAPIDRIVE_EXPORT FileFetchJob : public KGAPI2::FetchJob
     qulonglong fields() const;
 
   protected:
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
     KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-            const QByteArray &rawData) Q_DECL_OVERRIDE;
+            const QByteArray &rawData) override;
 
   private:
     class Private;
