@@ -26,8 +26,8 @@
 #include "file.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QString>
-#include <QtCore/QUrl>
+#include <QString>
+#include <QUrl>
 
 namespace KGAPI2
 {
