@@ -154,7 +154,7 @@ class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
     /**
      * @brief KGAPI2::Job::start implementation
      */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     /**
      * @brief KGAPI2::Job::handleReplyWithItems
@@ -163,7 +163,7 @@ class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
      * @param rawData
      */
     ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                             const QByteArray& rawData) Q_DECL_OVERRIDE;
+                                             const QByteArray& rawData) override;
 
   private:
     class Private;
