@@ -3,20 +3,21 @@
  *
  * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * GNU Lesser General Public License for more details.
  *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_LOCATIONFETCHJOB_H
@@ -60,7 +61,7 @@ class KGAPILATITUDE_EXPORT LocationFetchJob : public KGAPI2::FetchJob
      * @param account Account to authenticate the requests
      * @param parent
      */
-    explicit LocationFetchJob(const AccountPtr &account, QObject* parent = Q_NULLPTR);
+    explicit LocationFetchJob(const AccountPtr &account, QObject* parent = nullptr);
 
     /**
      * @brief Constructs a job that will fetch specific past user's location from
@@ -70,7 +71,7 @@ class KGAPILATITUDE_EXPORT LocationFetchJob : public KGAPI2::FetchJob
      * @param account Account to authenticate the requests
      * @param parent
      */
-    explicit LocationFetchJob(qlonglong timestamp, const AccountPtr &account, QObject* parent = Q_NULLPTR);
+    explicit LocationFetchJob(qlonglong timestamp, const AccountPtr &account, QObject* parent = nullptr);
 
     /**
      * @brief Destructor
@@ -94,7 +95,7 @@ class KGAPILATITUDE_EXPORT LocationFetchJob : public KGAPI2::FetchJob
     /**
      * @brief KGAPI2::Job::start implementation
      */
-    virtual void start();
+    void start() override;
 
     /**
      * @brief KGAPI2::FetchJob::handleReplyWithItems implementation
@@ -102,8 +103,8 @@ class KGAPILATITUDE_EXPORT LocationFetchJob : public KGAPI2::FetchJob
      * @param reply
      * @param rawData
      */
-    virtual ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                             const QByteArray& rawData);
+    ObjectsList handleReplyWithItems(const QNetworkReply *reply,
+                                             const QByteArray& rawData) override;
 
   private:
     class Private;
